@@ -164,7 +164,7 @@ class NumerousLogHandler:
     #TODO make a handler thread to schedule update to server!
 
 class NumerousClient:
-    def __init__(self, job_id=None, project=None, scenario=None, server=None, port=None, token=None, clear_data=None, no_log=False):
+    def __init__(self, job_id=None, project=None, scenario=None, server=None, port=None, token=None, clear_data=None, no_log=False, instance_id=None):
 
 
         self.job_states = JobStatus
@@ -180,7 +180,7 @@ class NumerousClient:
 
         self._complete = True
 
-        channel = self._init_channel(server=server, port=port)
+        channel = self._init_channel(server=server, port=port, instance_id=instance_id)
         stub = spm_pb2_grpc.SPMStub(channel)
 
         # TODO: Maybe reconsider
@@ -218,7 +218,7 @@ class NumerousClient:
     def complete_execution(self):
         self._base_client.CompleteExecution(spm_pb2.ExecutionMessage(project_id=self._project, scenario_id=self._scenario, job_id=self._job_id, execution_id=self._execution_id))
 
-    def _init_channel(self, server, port):
+    def _init_channel(self, server, port, instance_id=None):
         secure_channel = os.getenv('SECURE_CHANNEL', False)
         server = get_env(server, 'NUMEROUS_API_SERVER')
         port = get_env(port, 'NUMEROUS_API_PORT')
@@ -233,7 +233,9 @@ class NumerousClient:
         else:
             channel = grpc.insecure_channel(f'{server}:{port}')
 
-        channel = grpc.intercept_channel(channel, ValidationInterceptor(token=self._token))
+        vi = ValidationInterceptor(token=self._token, instance=instance_id)
+        self._instance = vi.instance
+        channel = grpc.intercept_channel(channel, vi)
         return channel
 
     def _init_logger(self):
